@@ -22,7 +22,7 @@ from drun.models.config import Config
 from drun.models.request import StepRequest
 from drun.models.step import Step
 from drun.models.validators import Validator
-from drun.models.report import RunReport
+from drun.models.report import RunReport, NotifyResult
 from drun.reporter.json_reporter import write_json
 from drun.runner.runner import Runner
 from drun.templating.engine import TemplateEngine
@@ -223,6 +223,92 @@ def parse_kv(items: List[str]) -> Dict[str, str]:
     return out
 
 
+def _sanitize_name(name: str) -> str:
+    """清理文件名，移除特殊字符"""
+    import re
+    name = name.lower()
+    name = name.replace(' ', '_')
+    name = name.replace('/', '_')
+    name = name.replace('-', '_')
+    # 移除其他特殊字符
+    name = re.sub(r'[^\w_]', '', name)
+    return name
+
+
+def _save_code_snippets(
+    items: List[tuple[Case, Dict[str, str]]],
+    output_dir: Optional[str],
+    languages: str,
+    env_store: Dict[str, Any],
+    timestamp: str,
+    log
+):
+    """保存代码片段到文件"""
+    from pathlib import Path
+    from drun.exporters.snippet import SnippetGenerator
+    
+    generator = SnippetGenerator()
+    
+    # 确定输出目录
+    if output_dir:
+        # 用户指定了目录，直接使用（不添加时间戳子目录）
+        target_dir = Path(output_dir)
+    else:
+        # 默认行为：使用 snippets/{timestamp}/
+        target_dir = Path("snippets") / timestamp
+    
+    target_dir.mkdir(parents=True, exist_ok=True)
+    
+    saved_files = []
+    is_multi_case = len(items) > 1
+    
+    for case, meta in items:
+        case_name = case.config.name or Path(meta.get('file', 'snippet')).stem
+        safe_case_name = _sanitize_name(case_name)
+        
+        # 遍历每个 step
+        for step_idx, step in enumerate(case.steps):
+            step_num = step_idx + 1
+            safe_step_name = _sanitize_name(step.name)
+            
+            # 生成文件名
+            if is_multi_case:
+                # 多个用例：step{N}_{case}_{step}_{lang}.{ext}
+                file_prefix = f"step{step_num}_{safe_case_name}_{safe_step_name}"
+            else:
+                # 单个用例：step{N}_{step}_{lang}.{ext}
+                file_prefix = f"step{step_num}_{safe_step_name}"
+            
+            # 确定要生成的语言
+            langs = ['curl', 'python'] if languages == 'all' else [languages]
+            
+            # 生成 Shell 脚本
+            if 'curl' in langs:
+                shell_file = target_dir / f"{file_prefix}_curl.sh"
+                content = generator.generate_shell_script_for_step(
+                    case, step_idx, len(case.steps), env_store
+                )
+                shell_file.write_text(content, encoding='utf-8')
+                shell_file.chmod(0o755)  # 添加执行权限
+                saved_files.append(shell_file.name)
+            
+            # 生成 Python 脚本
+            if 'python' in langs:
+                python_file = target_dir / f"{file_prefix}_python.py"
+                content = generator.generate_python_script_for_step(
+                    case, step_idx, len(case.steps), env_store
+                )
+                python_file.write_text(content, encoding='utf-8')
+                python_file.chmod(0o755)  # 添加执行权限
+                saved_files.append(python_file.name)
+    
+    # 输出保存信息
+    if saved_files:
+        log.info("[SNIPPET] Code snippets saved to %s/", target_dir)
+        for file in saved_files:
+            log.info("[SNIPPET] - %s", file)
+
+
 def load_env_file(path: Optional[str]) -> Dict[str, str]:
     # Kept for backward compat; now handled in load_environment
     if not path:
@@ -1072,36 +1158,29 @@ def list_tags(
             typer.echo(f"    • {case_name} -> {case_path}")
 
 
-@app.command()
-def run(
-    path: str = typer.Argument(..., help="要运行的文件或目录"),
-    k: Optional[str] = typer.Option(None, "-k", help="标签过滤表达式（支持 and/or/not）"),
-    vars: List[str] = typer.Option([], "--vars", help="变量覆盖 k=v（可重复）"),
-    failfast: bool = typer.Option(False, "--failfast", help="遇到第一个失败时停止"),
-    report: Optional[str] = typer.Option(None, "--report", help="输出 JSON 报告到文件"),
-    html: Optional[str] = typer.Option(None, "--html", help="输出 HTML 报告到文件（默认 reports/report-<timestamp>.html）"),
-    allure_results: Optional[str] = typer.Option(None, "--allure-results", help="输出 Allure 结果到目录（用于 allure generate）"),
-    log_level: str = typer.Option("INFO", "--log-level", help="日志级别"),
-    env_file: Optional[str] = typer.Option(None, "--env-file", help=".env 文件路径（默认 .env）"),
-    log_file: Optional[str] = typer.Option(None, "--log-file", help="输出控制台日志到文件（默认 logs/run-<ts>.log）"),
-    httpx_logs: bool = typer.Option(False, "--httpx-logs/--no-httpx-logs", help="显示 httpx 内部请求日志", show_default=False),
-    reveal_secrets: bool = typer.Option(True, "--reveal-secrets/--mask-secrets", help="在日志和报告中显示敏感字段明文（password、tokens）", show_default=True),
-    response_headers: bool = typer.Option(
-        False,
-        "--response-headers/--no-response-headers",
-        help="记录 HTTP 响应头（默认关闭）",
-        show_default=False,
-    ),
-    notify: Optional[str] = typer.Option(None, "--notify", help="通知渠道，逗号分隔：feishu,email,dingtalk"),
-    notify_only: Optional[str] = typer.Option(
-        None,
-        "--notify-only",
-        help="通知策略：failed|always（默认 $DRUN_NOTIFY_ONLY 或 'failed'）",
-        show_default=False,
-    ),
-    notify_attach_html: bool = typer.Option(False, "--notify-attach-html/--no-notify-attach-html", help="在邮件中附加 HTML 报告（如果启用邮件）", show_default=False),
+def _run_impl(
+    path: str,
+    k: Optional[str],
+    vars: List[str],
+    failfast: bool,
+    report: Optional[str],
+    html: Optional[str],
+    allure_results: Optional[str],
+    log_level: str,
+    env_file: Optional[str],
+    persist_env: Optional[str],
+    log_file: Optional[str],
+    httpx_logs: bool,
+    reveal_secrets: bool,
+    response_headers: bool,
+    notify: Optional[str],
+    notify_only: Optional[str],
+    notify_attach_html: bool,
+    no_snippet: bool,
+    snippet_output: Optional[str],
+    snippet_lang: str,
 ):
-    """运行测试用例或测试套件"""
+    """运行测试用例的核心实现"""
     # default timestamp; set up console logging first (no file) to avoid writing to a wrong file
     ts = time.strftime("%Y%m%d-%H%M%S")
     default_log = None  # will be decided after env is loaded
@@ -1229,6 +1308,9 @@ def run(
             typer.echo(line)
         raise typer.Exit(code=2)
 
+    # Determine persist env file (priority: --persist-env > --env-file > .env)
+    persist_file = persist_env or env_file or ".env"
+    
     # Execute
     runner = Runner(
         log=log,
@@ -1236,6 +1318,7 @@ def run(
         log_debug=(log_level.upper() == "DEBUG"),
         reveal_secrets=reveal_secrets,
         log_response_headers=response_headers,
+        persist_env_file=persist_file,
     )
     templater = TemplateEngine()
     instance_results = []
@@ -1429,23 +1512,140 @@ def run(
                     )
 
             log.info("[NOTIFY] Sending notifications via %d notifier(s)", len(notifiers))
+            
+            # Map notifier class name to channel name
+            notifier_channel_map = {
+                "FeishuNotifier": "feishu",
+                "EmailNotifier": "email",
+                "DingTalkNotifier": "dingtalk",
+            }
+            
+            # Set notify_channels for all cases
+            active_channels = [notifier_channel_map.get(n.__class__.__name__, n.__class__.__name__.lower()) for n in notifiers]
+            for case in report_obj.cases:
+                case.notify_channels = active_channels.copy()
+            
+            # Send notifications and collect results
+            notify_results: List[NotifyResult] = []
             for n in notifiers:
+                notifier_name = n.__class__.__name__
+                channel = notifier_channel_map.get(notifier_name, notifier_name.lower())
                 try:
-                    notifier_name = n.__class__.__name__
                     log.info("[NOTIFY] Sending via %s...", notifier_name)
                     n.send(report_obj, ctx)
                     log.info("[NOTIFY] %s notification sent successfully", notifier_name)
+                    notify_results.append(NotifyResult(channel=channel, status="success"))
                 except Exception as e:
-                    log.error("[NOTIFY] Failed to send via %s: %s", n.__class__.__name__, str(e))
+                    log.error("[NOTIFY] Failed to send via %s: %s", notifier_name, str(e))
+                    notify_results.append(NotifyResult(channel=channel, status="failed"))
+            
+            # Update notify_results for all cases
+            for case in report_obj.cases:
+                case.notify_results = notify_results.copy()
+            
+            # Regenerate HTML report with notification info
+            write_html(report_obj, html_target)
+            log.info("[NOTIFY] HTML report updated with notification status")
     except Exception as e:
         # never break main flow for notifications
         log.error("[NOTIFY] Notification module error: %s", str(e))
 
+    # 生成代码片段（默认行为）
+    if not no_snippet:
+        try:
+            _save_code_snippets(items, snippet_output, snippet_lang, env_store, ts, log)
+        except Exception as e:
+            log.error("[SNIPPET] Failed to generate code snippets: %s", str(e))
+
     log.info("[CASE] Logs written to %s", default_log)
     if s.get("failed", 0) > 0:
         raise typer.Exit(code=1)
 
 
+@app.command()
+def run(
+    path: str = typer.Argument(..., help="要运行的文件或目录"),
+    k: Optional[str] = typer.Option(None, "-k", help="标签过滤表达式（支持 and/or/not）"),
+    vars: List[str] = typer.Option([], "--vars", help="变量覆盖 k=v（可重复）"),
+    failfast: bool = typer.Option(False, "--failfast", help="遇到第一个失败时停止"),
+    report: Optional[str] = typer.Option(None, "--report", help="输出 JSON 报告到文件"),
+    html: Optional[str] = typer.Option(None, "--html", help="输出 HTML 报告到文件（默认 reports/report-<timestamp>.html）"),
+    allure_results: Optional[str] = typer.Option(None, "--allure-results", help="输出 Allure 结果到目录（用于 allure generate）"),
+    log_level: str = typer.Option("INFO", "--log-level", help="日志级别"),
+    env_file: Optional[str] = typer.Option(None, "--env-file", help=".env 文件路径（默认 .env）"),
+    persist_env: Optional[str] = typer.Option(None, "--persist-env", help="指定提取变量的持久化文件（默认：.env 或使用 --env-file 的文件）"),
+    log_file: Optional[str] = typer.Option(None, "--log-file", help="输出控制台日志到文件（默认 logs/run-<ts>.log）"),
+    httpx_logs: bool = typer.Option(False, "--httpx-logs/--no-httpx-logs", help="显示 httpx 内部请求日志", show_default=False),
+    reveal_secrets: bool = typer.Option(True, "--reveal-secrets/--mask-secrets", help="在日志和报告中显示敏感字段明文（password、tokens）", show_default=True),
+    response_headers: bool = typer.Option(
+        False,
+        "--response-headers/--no-response-headers",
+        help="记录 HTTP 响应头（默认关闭）",
+        show_default=False,
+    ),
+    notify: Optional[str] = typer.Option(None, "--notify", help="通知渠道，逗号分隔：feishu,email,dingtalk"),
+    notify_only: Optional[str] = typer.Option(
+        None,
+        "--notify-only",
+        help="通知策略：failed|always（默认 $DRUN_NOTIFY_ONLY 或 'failed'）",
+        show_default=False,
+    ),
+    notify_attach_html: bool = typer.Option(False, "--notify-attach-html/--no-notify-attach-html", help="在邮件中附加 HTML 报告（如果启用邮件）", show_default=False),
+    no_snippet: bool = typer.Option(False, "--no-snippet", help="禁用代码片段生成（默认会自动生成到 snippets/ 目录）"),
+    snippet_output: Optional[str] = typer.Option(None, "--snippet-output", help="自定义代码片段输出目录（默认为 snippets/<timestamp>/）"),
+    snippet_lang: str = typer.Option("all", "--snippet-lang", help="生成的语言: all|curl|python（默认 all）"),
+):
+    """运行测试用例或测试套件"""
+    return _run_impl(
+        path, k, vars, failfast, report, html, allure_results,
+        log_level, env_file, persist_env, log_file, httpx_logs,
+        reveal_secrets, response_headers, notify, notify_only,
+        notify_attach_html, no_snippet, snippet_output, snippet_lang
+    )
+
+
+@app.command("r")
+def r(
+    path: str = typer.Argument(..., help="要运行的文件或目录"),
+    k: Optional[str] = typer.Option(None, "-k", help="标签过滤表达式（支持 and/or/not）"),
+    vars: List[str] = typer.Option([], "--vars", help="变量覆盖 k=v（可重复）"),
+    failfast: bool = typer.Option(False, "--failfast", help="遇到第一个失败时停止"),
+    report: Optional[str] = typer.Option(None, "--report", help="输出 JSON 报告到文件"),
+    html: Optional[str] = typer.Option(None, "--html", help="输出 HTML 报告到文件（默认 reports/report-<timestamp>.html）"),
+    allure_results: Optional[str] = typer.Option(None, "--allure-results", help="输出 Allure 结果到目录（用于 allure generate）"),
+    log_level: str = typer.Option("INFO", "--log-level", help="日志级别"),
+    env_file: Optional[str] = typer.Option(None, "--env-file", help=".env 文件路径（默认 .env）"),
+    persist_env: Optional[str] = typer.Option(None, "--persist-env", help="指定提取变量的持久化文件（默认：.env 或使用 --env-file 的文件）"),
+    log_file: Optional[str] = typer.Option(None, "--log-file", help="输出控制台日志到文件（默认 logs/run-<ts>.log）"),
+    httpx_logs: bool = typer.Option(False, "--httpx-logs/--no-httpx-logs", help="显示 httpx 内部请求日志", show_default=False),
+    reveal_secrets: bool = typer.Option(True, "--reveal-secrets/--mask-secrets", help="在日志和报告中显示敏感字段明文（password、tokens）", show_default=True),
+    response_headers: bool = typer.Option(
+        False,
+        "--response-headers/--no-response-headers",
+        help="记录 HTTP 响应头（默认关闭）",
+        show_default=False,
+    ),
+    notify: Optional[str] = typer.Option(None, "--notify", help="通知渠道，逗号分隔：feishu,email,dingtalk"),
+    notify_only: Optional[str] = typer.Option(
+        None,
+        "--notify-only",
+        help="通知策略：failed|always（默认 $DRUN_NOTIFY_ONLY 或 'failed'）",
+        show_default=False,
+    ),
+    notify_attach_html: bool = typer.Option(False, "--notify-attach-html/--no-notify-attach-html", help="在邮件中附加 HTML 报告（如果启用邮件）", show_default=False),
+    no_snippet: bool = typer.Option(False, "--no-snippet", help="禁用代码片段生成（默认会自动生成到 snippets/ 目录）"),
+    snippet_output: Optional[str] = typer.Option(None, "--snippet-output", help="自定义代码片段输出目录（默认为 snippets/<timestamp>/）"),
+    snippet_lang: str = typer.Option("all", "--snippet-lang", help="生成的语言: all|curl|python（默认 all）"),
+):
+    """运行测试用例或测试套件（run 的简写）"""
+    return _run_impl(
+        path, k, vars, failfast, report, html, allure_results,
+        log_level, env_file, persist_env, log_file, httpx_logs,
+        reveal_secrets, response_headers, notify, notify_only,
+        notify_attach_html, no_snippet, snippet_output, snippet_lang
+    )
+
+
 @app.command("check")
 def check(
     path: str = typer.Argument(..., help="要验证的文件或目录"),
@@ -1777,6 +1977,7 @@ def init_project(
         "converts": "格式转换源文件目录",
         "reports": "报告输出目录",
         "logs": "日志输出目录",
+        "snippets": "代码片段输出目录",
         ".github/workflows": "GitHub Actions 工作流目录",
     }
 
@@ -1789,8 +1990,8 @@ def init_project(
     for subdir in convert_subdirs:
         (target_dir / "converts" / subdir).mkdir(parents=True, exist_ok=True)
 
-    # 在 reports 和 logs 目录放置 .gitkeep
-    for empty_dir in ["reports", "logs"]:
+    # 在 reports、logs 和 snippets 目录放置 .gitkeep
+    for empty_dir in ["reports", "logs", "snippets"]:
         gitkeep_path = target_dir / empty_dir / ".gitkeep"
         gitkeep_path.write_text(scaffolds.GITKEEP_CONTENT, encoding="utf-8")
 
@@ -1901,6 +2102,7 @@ def init_project(
         ("│       └── ", "sample_openapi.json", "OpenAPI 规范"),
         ("├── ", "reports/", "测试报告输出目录"),
         ("├── ", "logs/", "运行日志输出目录"),
+        ("├── ", "snippets/", "代码片段输出目录"),
         ("├── ", ".github/", "GitHub 配置目录"),
         ("│   └── ", "workflows/", "GitHub Actions 工作流"),
         ("│       └── ", "test.yml", "默认 CI 流水线"),
@@ -1921,7 +2123,7 @@ def init_project(
         else:
             typer.echo(full)
     typer.echo("")
-    typer.echo("9 directories, 19 files")
+    typer.echo("10 directories, 19 files")
 
     if skipped_files:
         typer.echo("")
@@ -1981,5 +2183,59 @@ def convert_openapi(
     )
 
 
+@app.command("s")
+def serve_reports(
+    port: int = typer.Option(8080, "--port", help="监听端口"),
+    host: str = typer.Option("0.0.0.0", "--host", help="监听地址 (0.0.0.0 允许外部访问)"),
+    reports_dir: str = typer.Option("reports", "--reports-dir", help="报告目录路径"),
+    reload: bool = typer.Option(False, "--reload/--no-reload", help="开发模式（热重载）"),
+    open_browser: bool = typer.Option(True, "--open/--no-open", help="自动打开浏览器"),
+):
+    """启动 Web Server 查看测试报告"""
+    try:
+        import uvicorn
+        import webbrowser
+        import threading
+    except ImportError:
+        typer.echo("[ERROR] FastAPI and uvicorn are required for the serve command.")
+        typer.echo("Install them with: pip install fastapi uvicorn")
+        raise typer.Exit(code=1)
+    
+    # Convert to absolute path and ensure directory exists
+    reports_path = Path(reports_dir).resolve()
+    if not reports_path.exists():
+        typer.echo(f"[WARN] Reports directory not found: {reports_dir}")
+        typer.echo(f"[INFO] Creating directory: {reports_dir}")
+        reports_path.mkdir(parents=True, exist_ok=True)
+    
+    # Pass absolute path to server via environment variable
+    os.environ["DRUN_REPORTS_DIR"] = str(reports_path)
+    
+    url = f"http://{host}:{port}"
+    typer.echo(f"[SERVER] Starting Drun Report Server")
+    typer.echo(f"[SERVER] Web UI: {url}")
+    typer.echo(f"[SERVER] API docs: {url}/docs")
+    typer.echo(f"[SERVER] Reports directory: {reports_path}")
+    typer.echo(f"[SERVER] Listening on: {host}:{port}")
+    if host == "0.0.0.0":
+        typer.echo(f"[SERVER] ⚠️  Server is accessible from public network")
+    typer.echo(f"[SERVER] Press Ctrl+C to stop")
+    
+    if open_browser and not reload and host in ["127.0.0.1", "localhost"]:
+        # Open browser after a short delay (only for local access)
+        threading.Timer(1.5, lambda: webbrowser.open(url)).start()
+    
+    try:
+        uvicorn.run(
+            "drun.server.app:app",
+            host=host,
+            port=port,
+            reload=reload,
+            log_level="info"
+        )
+    except KeyboardInterrupt:
+        typer.echo("\n[SERVER] Stopped")
+
+
 if __name__ == "__main__":
     app()
