@@ -9,7 +9,7 @@ from typing import List, Optional
 import httpx
 
 from .base import Notifier, NotifyContext
-from .format import build_text_message
+from .format import build_text_message, build_markdown_message
 from drun.models.report import RunReport
 from drun.utils.config import get_env_clean, get_system_name
 
@@ -42,16 +42,43 @@ class DingTalkNotifier(Notifier):
         return {"timestamp": ts, "sign": sign}
 
     def _send_json(self, payload: dict) -> None:
-        params = self._sign_params()
+        # 构建完整的 URL，包含签名参数
+        url = self.webhook
+        sign_params = self._sign_params()
+        if sign_params:
+            # 将签名参数附加到 URL，避免覆盖 access_token
+            timestamp = sign_params["timestamp"]
+            sign = sign_params["sign"]
+            url = f"{self.webhook}&timestamp={timestamp}&sign={sign}"
+        
         headers = {"Content-Type": "application/json"}
         with httpx.Client(timeout=self.timeout) as client:
-            _ = client.post(self.webhook, params=params, json=payload, headers=headers)
+            _ = client.post(url, json=payload, headers=headers)
 
     def send(self, report: RunReport, ctx: NotifyContext) -> None:  # pragma: no cover - integration
         if not self.webhook:
             return
         try:
-            text = build_text_message(report, html_path=ctx.html_path, log_path=ctx.log_path, topn=ctx.topn)
+            # 获取报告 URL（优先使用 REPORT_URL 环境变量）
+            report_url = get_env_clean("REPORT_URL")
+            if not report_url and ctx.html_path:
+                # 如果 html_path 是 HTTP URL，直接使用
+                if ctx.html_path.startswith("http://") or ctx.html_path.startswith("https://"):
+                    report_url = ctx.html_path
+            
+            # 构建消息内容 - 根据 style 选择不同的格式
+            html_path_display = report_url if report_url else ctx.html_path
+            
+            if self.style == "markdown":
+                # 使用 Markdown 格式
+                text = build_markdown_message(report, html_path=html_path_display, log_path=ctx.log_path, topn=ctx.topn)
+                # 如果有额外的报告 URL，添加链接（避免重复）
+                if report_url and not html_path_display:
+                    text = text + f"[📊 查看详细报告]({report_url})\n\n"
+            else:
+                # 使用纯文本格式
+                text = build_text_message(report, html_path=html_path_display, log_path=ctx.log_path, topn=ctx.topn)
+            
             at_block = {
                 "atMobiles": self.at_mobiles,
                 "isAtAll": self.at_all,
