@@ -6,7 +6,7 @@ import os
 from pathlib import Path
 from typing import Any, List, Dict
 
-from drun.models.report import RunReport, CaseInstanceResult, StepResult, AssertionResult
+from drun.models.report import RunReport, CaseInstanceResult, StepResult, AssertionResult, NotifyResult
 from drun.utils.config import get_system_name
 
 
@@ -344,11 +344,23 @@ def _build_case(case: CaseInstanceResult) -> str:
 
     meta_html = f" <span class='case-meta st-meta'>{_escape_html(case_meta)}</span>" if case_meta else ""
 
+    # Notification info
+    notify_channels = ", ".join(case.notify_channels) if case.notify_channels else "-"
+    status_icons = []
+    for r in case.notify_results:
+        if r.status == "success":
+            status_icons.append(f"<span class='ok'>✓</span>")
+        else:
+            status_icons.append(f"<span class='err'>✗</span>")
+    notify_status = " ".join(status_icons) if status_icons else "-"
+
     head = (
         "<div class='head'>"
         f"<div><div><b>用例：</b>{_escape_html(case.name)}{meta_html}</div>{params_html}</div>"
         f"<div><span class='pill {case.status}'>{case.status}</span>"
-        f"<span class='muted' style='margin-left:8px;'>{case.duration_ms:.1f} ms</span></div>"
+        f"<span class='muted' style='margin-left:8px;'>{case.duration_ms:.1f} ms</span>"
+        f"<span class='muted' style='margin-left:8px;'>通知: {_escape_html(notify_channels)}</span>"
+        f"<span class='muted' style='margin-left:8px;'>状态: {notify_status}</span></div>"
         "</div>"
     )
 
@@ -410,6 +422,11 @@ def write_html(report: RunReport, outfile: str | Path) -> None:
   .panel .p-head .actions { display:flex; gap:6px; }
   .panel pre, .panel table { margin:0; padding:10px; overflow:auto; max-height: 360px; }
   .panel[data-section='curl'] pre { white-space: pre; overflow-x: auto; word-break: normal; }
+  /* Fixed height for request and response body panels */
+  .panel[data-section='request-body'] pre { height: 360px; min-height: 360px; overflow-y: auto; overflow-x: auto; }
+  .panel[data-section='response-body']:not([data-stream='true']) pre { height: 360px; min-height: 360px; overflow-y: auto; overflow-x: auto; }
+  .panel[data-section='response-body'][data-stream='true'] .view-content { height: 360px; min-height: 360px; overflow-y: auto; overflow-x: auto; }
+  .panel[data-section='response-body'][data-stream='true'] .view-content pre { max-height: none; overflow: visible; height: auto; }
   table { width: 100%; border-collapse: collapse; table-layout: fixed; }
   th { padding: 6px 8px; border-bottom: 1px solid var(--border); vertical-align: top; text-align: left; font-weight: 600; }
   td { padding: 6px 8px; border-bottom: 1px solid var(--border); vertical-align: top; word-break: break-word; }
@@ -435,7 +452,7 @@ def write_html(report: RunReport, outfile: str | Path) -> None:
   .panel .p-head button:hover { border-color:var(--accent); }
   .panel .p-head button.copied { border-color:var(--ok); background:#dafbe1; color:var(--ok); font-weight:500; }
   .panel .p-head button.copy-failed { border-color:var(--fail); background:#ffebe9; color:var(--fail); font-weight:500; }
-  .footer { margin-top: 24px; color: var(--muted); font-size: 12px; }
+  .footer { position: fixed; bottom: 0; left: 0; right: 0; text-align: center; padding: 12px 0; background: #ffffff; border-top: 1px solid #d0d7de; color: var(--muted); font-size: 12px; }
   .collapsed .body { display: none; }
   /* Streaming response styles */
   .stream-stats { display: flex; gap: 6px; margin-left: auto; margin-right: 8px; }
