@@ -27,17 +27,44 @@ class Runner:
         log_debug: bool = False,
         reveal_secrets: bool = True,
         log_response_headers: bool = True,
+        persist_env_file: str = ".env",
     ) -> None:
         self.log = log
         self.failfast = failfast
         self.log_debug = log_debug
         self.reveal = reveal_secrets
         self.log_response_headers = log_response_headers
+        self.persist_env_file = persist_env_file
         self.templater = TemplateEngine()
 
     def _render(self, data: Any, variables: Dict[str, Any], functions: Dict[str, Any] | None = None, envmap: Dict[str, Any] | None = None) -> Any:
         return self.templater.render_value(data, variables, functions, envmap)
 
+    def _collect_render_diffs(self, original: Any, rendered: Any, path: str = "") -> List[tuple]:
+        """Collect before/after differences for variable substitution."""
+        diffs = []
+        if isinstance(original, str):
+            # Check if original contains variable references
+            if '$' in original and original != str(rendered):
+                diffs.append((original, rendered))
+        elif isinstance(original, dict) and isinstance(rendered, dict):
+            for key in original:
+                if key in rendered:
+                    diffs.extend(self._collect_render_diffs(original[key], rendered[key], f"{path}.{key}"))
+        elif isinstance(original, list) and isinstance(rendered, list):
+            for i, (o, r) in enumerate(zip(original, rendered)):
+                diffs.extend(self._collect_render_diffs(o, r, f"{path}[{i}]"))
+        return diffs
+
+    def _log_render_diffs(self, req_dict: Dict[str, Any], req_rendered: Dict[str, Any]) -> None:
+        """Log variable substitution before/after values."""
+        if not self.log:
+            return
+        diffs = self._collect_render_diffs(req_dict, req_rendered)
+        for orig, rendered in diffs:
+            rendered_str = str(rendered) if not isinstance(rendered, str) else rendered
+            self.log.info(f"[RENDER] {orig} → {rendered_str}")
+
     def _build_client(self, case: Case) -> HTTPClient:
         cfg = case.config
         return HTTPClient(
@@ -532,6 +559,9 @@ class Runner:
                 if self.log:
                     self.log.info(f"[STEP] Start: {rendered_step_name}")
 
+                    # Log variable substitution before/after values
+                    self._log_render_diffs(req_dict, req_rendered)
+
                     # Print step variables if present
                     step_vars = step.variables or {}
                     if step_vars:
@@ -700,6 +730,89 @@ class Runner:
                     ctx.set_base(var, val)
                     if self.log:
                         self.log.info(f"[EXTRACT] {var} = {val!r} from {expr}")
+                
+                # Update to memory environment variables (for immediate use in subsequent cases)
+                if extracts and envmap is not None:
+                    from drun.utils.env_writer import to_env_var_name
+                    for var_name, value in extracts.items():
+                        env_key = to_env_var_name(var_name)
+                        envmap[env_key] = value
+                        envmap[var_name] = value
+                
+                # Auto-persist extracted variables to env file
+                if extracts:
+                    from pathlib import Path
+                    from drun.utils.env_writer import (
+                        write_env_variable,
+                        write_yaml_variable,
+                        to_env_var_name
+                    )
+                    
+                    env_path = Path(self.persist_env_file)
+                    is_yaml = env_path.suffix.lower() in {'.yaml', '.yml'}
+                    
+                    for var_name, value in extracts.items():
+                        try:
+                            env_key = to_env_var_name(var_name)
+                            
+                            if is_yaml:
+                                write_yaml_variable(str(env_path), var_name, value)
+                            else:
+                                write_env_variable(str(env_path), var_name, value)
+                            
+                            if self.log:
+                                self.log.info(
+                                    f"[PERSIST] {var_name} → {env_key} = {value!r} "
+                                    f"(已写入 {self.persist_env_file})"
+                                )
+                        except Exception as e:
+                            if self.log:
+                                self.log.warning(f"[PERSIST] 写入失败 {var_name}: {e}")
+                
+                # Export data to CSV
+                if step.export:
+                    if "csv" in step.export:
+                        csv_config = step.export["csv"]
+                        
+                        # 渲染配置中的模板变量（支持 ${now()} 等）
+                        rendered_config = self._render(csv_config, variables, funcs, envmap)
+                        
+                        # 提取数据
+                        data_expr = rendered_config.get("data")
+                        if not data_expr:
+                            raise ValueError("export.csv.data 字段是必填的")
+                        
+                        array_data = self._eval_extract(data_expr, resp_obj)
+                        
+                        # 导出到 CSV
+                        from pathlib import Path
+                        from drun.utils.data_exporter import export_to_csv
+                        
+                        try:
+                            # 获取项目根目录（与 CSV 参数化保持一致）
+                            from drun.loader.hooks import find_hooks
+                            hooks_file = find_hooks(Path.cwd())
+                            base_dir = hooks_file.parent if hooks_file else Path.cwd()
+                            
+                            row_count = export_to_csv(
+                                data=array_data,
+                                file_path=rendered_config["file"],
+                                columns=rendered_config.get("columns"),
+                                encoding=rendered_config.get("encoding", "utf-8"),
+                                mode=rendered_config.get("mode", "overwrite"),
+                                delimiter=rendered_config.get("delimiter", ","),
+                                base_dir=base_dir,
+                            )
+                            
+                            if self.log:
+                                self.log.info(
+                                    f"[EXPORT CSV] {row_count} rows → {rendered_config['file']}"
+                                )
+                        except Exception as e:
+                            if self.log:
+                                self.log.error(f"[EXPORT CSV] 导出失败: {e}")
+                            raise
+                
                 # Update variables after extraction so validate can use them
                 variables = ctx.get_merged(global_vars)
 
