@@ -9,6 +9,7 @@ from .templates import (
     CONVERTS_README,
     CSV_DATA_TESTCASE,
     CSV_DATA_TESTSUITE,
+    CSV_EXPORT_TESTCASE,
     CSV_USERS_SAMPLE,
     DB_ASSERT_TESTCASE,
     DEMO_TESTCASE,
@@ -34,6 +35,7 @@ __all__ = [
     "CONVERTS_README",
     "CSV_DATA_TESTCASE",
     "CSV_DATA_TESTSUITE",
+    "CSV_EXPORT_TESTCASE",
     "CSV_USERS_SAMPLE",
     "DB_ASSERT_TESTCASE",
     "DEMO_TESTCASE",
