@@ -5,10 +5,71 @@ import re
 import ast
 import operator as op
 import os
+import json
 
 from .builtins import BUILTINS
 
 
+def _try_parse_json(value: Any) -> Any:
+    """尝试将字符串值解析为 JSON 数组、对象或基本类型。
+    
+    自动识别并转换：
+    1. JSON 数组: ["item1", "item2"] 或 ['item1', 'item2']
+    2. JSON 对象: {"key": "value"}
+    3. 布尔值: true/false → True/False
+    4. null 值: null → None
+    5. 整数: 23 → 23
+    6. 浮点数: 19.99 → 19.99
+    7. 普通字符串保持不变
+    """
+    if not isinstance(value, str):
+        return value
+    
+    stripped = value.strip()
+    
+    # 1. 尝试解析 JSON 数组或对象
+    if (stripped.startswith('[') and stripped.endswith(']')) or \
+       (stripped.startswith('{') and stripped.endswith('}')):
+        try:
+            # 先尝试标准 JSON 解析
+            return json.loads(stripped)
+        except (json.JSONDecodeError, ValueError):
+            # 如果失败，尝试将 Python 格式的单引号转换为双引号
+            try:
+                # 简单替换：将单引号替换为双引号（仅适用于简单情况）
+                normalized = stripped.replace("'", '"')
+                return json.loads(normalized)
+            except (json.JSONDecodeError, ValueError):
+                pass
+    
+    # 2. 尝试解析布尔值（不区分大小写）
+    lower = stripped.lower()
+    if lower == 'true':
+        return True
+    if lower == 'false':
+        return False
+    
+    # 3. 尝试解析 null
+    if lower == 'null':
+        return None
+    
+    # 4. 尝试解析数字
+    # 4a. 整数（包括负数）
+    if stripped.lstrip('-').isdigit():
+        return int(stripped)
+    
+    # 4b. 浮点数
+    try:
+        # 只有在包含小数点时才尝试解析为浮点数
+        if '.' in stripped:
+            return float(stripped)
+    except ValueError:
+        pass
+    
+    # 5. 无法识别，返回原字符串
+    return value
+
+
 def _normalize_simple_tokens(text: str) -> str:
     """Expand bare $var tokens into ${var} for downstream evaluation."""
 
@@ -136,8 +197,10 @@ class TemplateEngine:
                 # Inject ENV function that reads from provided envmap or OS
                 def ENV(name: str, default: Any = None) -> Any:  # noqa: N802 - uppercase by design
                     if envmap is not None and name in envmap:
-                        return envmap.get(name)
-                    return os.environ.get(name, default)
+                        value = envmap.get(name)
+                    else:
+                        value = os.environ.get(name, default)
+                    return _try_parse_json(value)
 
                 dyn_funcs: Dict[str, Callable[..., Any]] = {"ENV": ENV}
                 ctx: Dict[str, Any] = {**BUILTINS, **dyn_funcs, **(functions or {}), **variables}
@@ -179,8 +242,10 @@ class TemplateEngine:
 
         def ENV(name: str, default: Any = None) -> Any:  # noqa: N802
             if envmap is not None and name in envmap:
-                return envmap.get(name)
-            return os.environ.get(name, default)
+                value = envmap.get(name)
+            else:
+                value = os.environ.get(name, default)
+            return _try_parse_json(value)
 
         ctx: Dict[str, Any] = {**BUILTINS, **(functions or {}), **(variables or {}), **(extra_ctx or {}), "ENV": ENV}
         try:
